import {
  select,
  scaleLinear,
  scaleOrdinal,
  extent,
  axisBottom,
  axisLeft,
  csv,
  interpolateRainbow
} from 'd3';

import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { scatterPlot } from './scatterPlot';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const scatterPlotG = svg.append('g');
const colorLegendG = svg.append('g')
    .attr('transform',`translate(860,80)`);


const colorScale = scaleOrdinal();
const colorValue = d => d.Month;



const title = 'London Monthly Air Quality: PM2.5 vs. PM10 Particulates';
const xValue = d => d['Roadside_PM2.5'];
//const xValue = d => d.Roadside_Ozone;
const xAxisLabel = 'Roadside PM2.5 (ug/m3)';

  
const yValue = d => d.Roadside_PM10;
const circleRadius = 10;
const yAxisLabel = 'Roadside PM10 (ug/m3)';

  
const margin = { top: 60, right: 130, bottom: 88, left: 150 };
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

let data;
let selectedColorValue;


const onClick = d => {
  selectedColorValue = d;
  render();
}

loadAndProcessData()
  .then(d => {
    data = d
    render()
});


const render = () => {
  
  colorScale
    .domain(data.map(colorValue))
    .domain(colorScale.domain().sort().reverse());
  
  const n = colorScale.domain().length;
  
  colorScale.range(colorScale.domain().map((d, i) =>
    interpolateRainbow(i / (n + 1))
  ));

  scatterPlotG.call(scatterPlot,{
    data,
    colorValue,
    colorScale,
    selectedColorValue,
    width,
    height,
    margin,
    title,
    xValue,
    xAxisLabel,
    yValue,
    yAxisLabel, 
    circleRadius,
    innerWidth,
    innerHeight
  });

  colorLegendG.call(colorLegend,{
    colorScale,
    circleRadius: 10,
    spacing: 21,
    textOffset: 16,
    backgroundRectWidth:85,
    onClick,
    selectedColorValue
  });
};